==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/npc/NPCRoleFastEntity.java <==
package cc.thonly.reverie_dreams.entity.npc;

import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import net.minecraft.class_11368;
import net.minecraft.class_1266;
import net.minecraft.class_1299;
import net.minecraft.class_1306;
import net.minecraft.class_1308;
import net.minecraft.class_1315;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_3218;
import net.minecraft.class_3730;
import net.minecraft.class_5425;
import cc.thonly.reverie_dreams.data.skin.SkinType;
import org.jetbrains.annotations.Nullable;

public class NPCRoleFastEntity extends class_1308 {
    private class_11368 view;
    private SkinType skinType;

    public NPCRoleFastEntity(class_1299<? extends class_1308> entityType, class_1937 world) {
        super(entityType, world);
    }

    public NPCRoleFastEntity(class_1299<? extends class_1308> entityType, class_1937 world, SkinType skinType) {
        super(entityType, world);
        this.skinType = skinType;
    }

    @Override
    public void method_5773() {
        super.method_5773();
        if (!(this.method_37908() instanceof class_3218)) {
            return;
        }
        BaseNPCLikeEntity baseNPCRole = RDEntityTypes.NPC_ROLE_ENTITY.method_5883(this.method_37908(), class_3730.field_16471);
        if (baseNPCRole == null) {
            return;
        }
        if (this.view != null) {
            baseNPCRole.method_5651(this.view);
        }
        baseNPCRole.method_33574(this.method_19538());
        baseNPCRole.method_36457(this.method_36455());
        baseNPCRole.method_36456(this.method_36454());
        baseNPCRole.method_5826(this.method_5667());
        baseNPCRole.setSkinType(this.skinType);
        baseNPCRole.method_5665(class_2561.method_43471(this.method_5864().method_5882()));
        this.method_31472();
        this.method_37908().method_8649(baseNPCRole);
    }

    @Override
    public @Nullable class_1315 method_5943(class_5425 world, class_1266 difficulty, class_3730 spawnReason, @Nullable class_1315 entityData) {
        return super.method_5943(world, difficulty, spawnReason, entityData);
    }

    @Override
    public void method_5651(class_11368 view) {
        super.method_5651(view);
        this.view = view;
    }

    @Override
    public class_1306 method_6068() {
        return class_1306.field_6183;
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/npc/NPCRoleFastEntity.java <==
package cc.thonly.reverie_dreams.entity.npc;

import cc.thonly.reverie_dreams.data.skin.SkinType;
import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import net.minecraft.class_11368;
import net.minecraft.class_1266;
import net.minecraft.class_1299;
import net.minecraft.class_1306;
import net.minecraft.class_1308;
import net.minecraft.class_1315;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_3218;
import net.minecraft.class_3730;
import net.minecraft.class_5425;
import net.minecraft.world.entity.*;
import org.jetbrains.annotations.Nullable;

public class NPCRoleFastEntity extends class_1308 {
    private class_11368 view;
    private SkinType skinType;

    public NPCRoleFastEntity(class_1299<? extends class_1308> entityType, class_1937 world) {
        super(entityType, world);
    }

    public NPCRoleFastEntity(class_1299<? extends class_1308> entityType, class_1937 world, SkinType skinType) {
        super(entityType, world);
        this.skinType = skinType;
    }

    @Override
    public void method_5773() {
        super.method_5773();
        if (!(this.method_37908() instanceof class_3218)) {
            return;
        }
        BaseNPCLikeEntity baseNPCRole = RDEntityTypes.NPC_ROLE.method_5883(this.method_37908(), class_3730.field_16471);
        if (baseNPCRole == null) {
            return;
        }
        if (this.view != null) {
            baseNPCRole.method_5651(this.view);
        }
        baseNPCRole.method_33574(this.method_19538());
        baseNPCRole.method_36457(this.method_36455());
        baseNPCRole.method_36456(this.method_36454());
        baseNPCRole.method_5826(this.method_5667());
        baseNPCRole.setSkinType(this.skinType);
        baseNPCRole.method_5665(class_2561.method_43471(this.method_5864().method_5882()));
        this.method_31472();
        this.method_37908().method_8649(baseNPCRole);
    }

    @Override
    public @Nullable class_1315 method_5943(class_5425 world, class_1266 difficulty, class_3730 spawnReason, @Nullable class_1315 entityData) {
        return super.method_5943(world, difficulty, spawnReason, entityData);
    }

    @Override
    public void method_5651(class_11368 view) {
        super.method_5651(view);
        this.view = view;
    }

    @Override
    public class_1306 method_6068() {
        return class_1306.field_6183;
    }
}
